# AgentConnectorUpstreamBufferStats

Statistics related to upstream buffer management 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**avg_latency_ms** | **int** | The average latency in milliseconds | 
**receive_buffer_size_bytes** | **int** | The current receive buffer size used by upstream sockets. | 
**num_upstream_connections** | **int** | The current number of upstream connections that are being monitored. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


